@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 # $File: //member/autrijus/PAR/script/par.pl $ $Author: autrijus $
-# $Revision: #47 $ $Change: 4749 $ $DateTime: 2003/03/17 01:06:47 $ vim: expandtab shiftwidth=4
+# $Revision: #50 $ $Change: 4879 $ $DateTime: 2003/03/22 17:11:38 $ vim: expandtab shiftwidth=4
 
 package __par_pl;
 
@@ -135,23 +135,22 @@ followed by a 8-bytes magic string: "C<\012PAR.pm\012>".
 my $quiet = !$ENV{PAR_DEBUG};
 
 # fix $0 if invoked from PATH
-unless (-f $0) {
-    my %Config;
-    $Config{path_sep} = ($^O =~ /^MSWin/ ? ';' : ':');
-    $Config{_exe} = ($^O =~ /^MSWin|OS2/ ? '.exe' : '');
-    $Config{_delim} = ($^O =~ /^MSWin|OS2/ ? '\\' : '/');
+my %Config = (
+    path_sep    => ($^O =~ /^MSWin/ ? ';' : ':'),
+    _exe        => ($^O =~ /^(?:MSWin|OS2|cygwin)/ ? '.exe' : ''),
+    _delim      => ($^O =~ /^MSWin|OS2/ ? '\\' : '/'),
+);
 
-    if (-f "$0$Config{_exe}") {
-        $0 = "$0$Config{_exe}";
-    }
-    else {
-        foreach my $dir (split /$Config{path_sep}/, $ENV{PATH}) {
-            $dir =~ s/\Q$Config{_delim}\E$//;
-            (($0 = "$dir$Config{_delim}$0$Config{_exe}"), last)
-                if -f "$dir$Config{_delim}$0$Config{_exe}";
-            (($0 = "$dir$Config{_delim}$0"), last)
-                if -f "$dir$Config{_delim}$0";
-        }
+if (-s "$0$Config{_exe}") {
+    $0 = "$0$Config{_exe}";
+}
+elsif (!-s $0) {
+    foreach my $dir (split /$Config{path_sep}/, $ENV{PATH}) {
+        $dir =~ s/\Q$Config{_delim}\E$//;
+        (($0 = "$dir$Config{_delim}$0$Config{_exe}"), last)
+            if -s "$dir$Config{_delim}$0$Config{_exe}";
+        (($0 = "$dir$Config{_delim}$0"), last)
+            if -s "$dir$Config{_delim}$0";
     }
 }
 
@@ -332,7 +331,7 @@ if ($out) {
     my $loader = scalar <_FH>;
     $loader =~ s/
         ^=(?:head\d|pod|begin|item|over|for|back|end)\b.*?
-        ^=cut\s*$
+        ^=cut\b[^\n]*$
         \n*
     //smgx if !$ENV{PAR_VERBATIM} and $loader =~ /^(?:#!|\@rem)/;
     print OUT $loader;
@@ -389,7 +388,7 @@ if ($out) {
             my $content = <FILE>;
             $content =~ s/
                 ^=(?:head\d|pod|begin|item|over|for|back|end)\b.*?
-                ^=cut\s*$
+                ^=cut\b[^\n]*$
                 \n*
             //smgx if !$ENV{PAR_VERBATIM} and lc($name) =~ /\.(?:pm|ix|al)$/i;
             close FILE;
@@ -586,6 +585,20 @@ Please send bug reports to E<lt>bug-par@rt.cpan.orgE<gt>.
 
 Copyright 2002, 2003 by Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>.
 
+Neither this program nor the associated L<parl> program impose any
+licensing restrictions on files generated by their execution, in
+accordance with the 8th article of the Artistic License:
+
+    "Aggregation of this Package with a commercial distribution is
+    always permitted provided that the use of this Package is embedded;
+    that is, when no overt attempt is made to make this Package's
+    interfaces visible to the end user of the commercial distribution.
+    Such use shall not be construed as a distribution of this Package."
+
+Therefore, you are absolutely free to place any license on the resulting
+executable, as long as the packed 3rd-party libraries are also available
+under the Artistic License.
+
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
